Crate posturn

source ·

Re-exports

Modules

Structs

  • Allows a game coroutine to yield Events to be processed by the UI layer. Also allows read/write access to the game state via the shared host.

Traits

  • Trait defining a game that can be played via a Host.