posturn
0.2.0
All Items
Re-exports
Modules
Structs
Traits
Crate
posturn
source
·
[
−
]
Re-exports

pub use host::
Host
;
pub use
genawaiter
;
Modules

host
Structs

Context
Allows a game coroutine to yield
Event
s
to be processed by the UI layer. Also allows read/write access to the game state via the shared
host
.
Traits

Play
Trait defining a game that can be played via a
Host
.